@@ -14,8 +14,18 @@ impl ResticCreate {
         let restic = GenericExecutable::find("restic")?;
         let tags = tags.into_iter().map(|a| a.to_string()).collect::<Vec<_>>().join(",");
         
+        // Get the command specific flags
+        let flags = config.restic.flags.as_ref()
+            .and_then(|f| f.backup.clone())
+            .unwrap_or(Vec::new());
+
+        // Create the executable flags
+        let args = vec!["backup", "--tag", &tags].into_iter()
+            .chain(flags.iter().map(|f| f.as_str()))
+            .chain(vec![config.restic.dir.as_str()]);
+
         // Create the executable
-        let mut exec = GenericExecutable::new(restic, ["backup", "--tag", &tags, &config.restic.dir]);
+        let mut exec = GenericExecutable::new(restic, args);
         exec.set_envs(config.to_env()?);
         Ok(Self { exec })
     }
